package com.steerinfo.dil.model;

import com.steerinfo.framework.model.IBasePO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.math.BigDecimal;
import java.util.Date;

@ApiModel(value="船运计费账单")
public class BmsshipStatement implements IBasePO<BigDecimal> {
    /**
     * 主键ID(STATEMENT_ID,DECIMAL,0)
     */
    @ApiModelProperty(value="主键ID",required=true)
    private BigDecimal statementId;

    /**
     * 账单编号(STATEMENT_NO,VARCHAR,200)
     */
    @ApiModelProperty(value="账单编号",required=false)
    private String statementNo;

    /**
     * 支付单位ID(STATEMENT_SHIPPER_ID,DECIMAL,0)
     */
    @ApiModelProperty(value="支付单位ID",required=false)
    private BigDecimal statementShipperId;

    /**
     * 总金额(STATEMENT_TOTAL_AMOUNT,DECIMAL,0)
     */
    @ApiModelProperty(value="总金额",required=false)
    private BigDecimal statementTotalAmount;

    /**
     * 账单日期（默认每月截至20号）(STATEMENT_DATE,TIMESTAMP,7)
     */
    @ApiModelProperty(value="账单日期（默认每月截至20号）",required=false)
    private Date statementDate;

    /**
     * 记录创建人(INSERT_USERNAME,VARCHAR,20)
     */
    @ApiModelProperty(value="记录创建人",required=false)
    private String insertUsername;

    /**
     * 记录创建时间(INSERT_TIME,TIMESTAMP,7)
     */
    @ApiModelProperty(value="记录创建时间",required=false)
    private Date insertTime;

    /**
     * 记录修改人(UPDATE_USERNAME,VARCHAR,20)
     */
    @ApiModelProperty(value="记录修改人",required=false)
    private String updateUsername;

    /**
     * 记录修改时间(UPDATE_TIME,TIMESTAMP,7)
     */
    @ApiModelProperty(value="记录修改时间",required=false)
    private Date updateTime;

    /**
     * 记录创建或修改备注(INSERT_UPDATE_REMARK,VARCHAR,100)
     */
    @ApiModelProperty(value="记录创建或修改备注",required=false)
    private String insertUpdateRemark;

    /**
     * 费用类型（1：二程船水运费；2：二程船装卸费；3：三程船水运费；4：三程船装卸费；5：水分质检费用；6：进口矿火运费；7：进口矿装卸费）(STATEMENT_TYPE,VARCHAR,20)
     */
    @ApiModelProperty(value="费用类型（1：二程船水运费；2：二程船装卸费；3：三程船水运费；4：三程船装卸费；5：水分质检费用；6：进口矿火运费；7：进口矿装卸费）",required=false)
    private String statementType;

    /**
     * 批次ID(BATCH_ID,DECIMAL,0)
     */
    @ApiModelProperty(value="批次ID",required=false)
    private BigDecimal batchId;

    /**
     * 金蝶核准金额(EAS_AMOUNT,DECIMAL,0)
     */
    @ApiModelProperty(value="金蝶核准金额",required=false)
    private BigDecimal easAmount;

    /**
     * 吨位，如果是预开状态则是预开吨位，如果是结算状态则是开票吨位(TOTAL_WET_TON,DECIMAL,0)
     */
    @ApiModelProperty(value="吨位，如果是预开状态则是预开吨位，如果是结算状态则是开票吨位",required=false)
    private BigDecimal totalWetTon;

    /**
     * 结算状态（0：已预开；1：已结算）(STATEMENT_STATUS,DECIMAL,0)
     */
    @ApiModelProperty(value="结算状态（0：已预开；1：已结算）",required=false)
    private BigDecimal statementStatus;

    /**
     * 已预开吨位(TOTAL_PREVIEW_TON,DECIMAL,0)
     */
    @ApiModelProperty(value="已预开吨位",required=false)
    private BigDecimal totalPreviewTon;

    /**
     * 已预开金额(TOTAL_PREVIEW_FEE,DECIMAL,0)
     */
    @ApiModelProperty(value="已预开金额",required=false)
    private BigDecimal totalPreviewFee;

    /**
     * 单价ID(UNIT_PRICE_ID,DECIMAL,0)
     */
    @ApiModelProperty(value="单价ID",required=false)
    private BigDecimal unitPriceId;

    /**
     * 水分检测费总和(TOTAL_WATER_FEE,DECIMAL,0)
     */
    @ApiModelProperty(value="水分检测费总和",required=false)
    private BigDecimal totalWaterFee;

    /**
     * 总装船吨位(TOTAL_LOAD_TON,DECIMAL,0)
     */
    @ApiModelProperty(value="总装船吨位",required=false)
    private BigDecimal totalLoadTon;

    /**
     * 总计装船比例(TOTAL_LOAD_PERCENT,DECIMAL,0)
     */
    @ApiModelProperty(value="总计装船比例",required=false)
    private BigDecimal totalLoadPercent;

    /**
     * 总计结算吨位(TOTAL_BALANCE_TON,DECIMAL,0)
     */
    @ApiModelProperty(value="总计结算吨位",required=false)
    private BigDecimal totalBalanceTon;

    /**
     * 离港日期(RESULT_OUT_PORT_TIME,VARCHAR,50)
     */
    @ApiModelProperty(value="离港日期",required=false)
    private String resultOutPortTime;

    /**
     * 发票编号(BILL_NO,VARCHAR,50)
     */
    @ApiModelProperty(value="发票编号",required=false)
    private String billNo;

    private static final long serialVersionUID = 1L;

    @Override
    public BigDecimal getId() {
        return this.statementId;
    }

    @Override
    public void setId(BigDecimal statementId) {
        this.statementId = statementId;
    }

    public BigDecimal getStatementId() {
        return statementId;
    }

    public void setStatementId(BigDecimal statementId) {
        this.statementId = statementId;
    }

    public String getStatementNo() {
        return statementNo;
    }

    public void setStatementNo(String statementNo) {
        this.statementNo = statementNo == null ? null : statementNo.trim();
    }

    public BigDecimal getStatementShipperId() {
        return statementShipperId;
    }

    public void setStatementShipperId(BigDecimal statementShipperId) {
        this.statementShipperId = statementShipperId;
    }

    public BigDecimal getStatementTotalAmount() {
        return statementTotalAmount;
    }

    public void setStatementTotalAmount(BigDecimal statementTotalAmount) {
        this.statementTotalAmount = statementTotalAmount;
    }

    public Date getStatementDate() {
        return statementDate;
    }

    public void setStatementDate(Date statementDate) {
        this.statementDate = statementDate;
    }

    public String getInsertUsername() {
        return insertUsername;
    }

    public void setInsertUsername(String insertUsername) {
        this.insertUsername = insertUsername == null ? null : insertUsername.trim();
    }

    public Date getInsertTime() {
        return insertTime;
    }

    public void setInsertTime(Date insertTime) {
        this.insertTime = insertTime;
    }

    public String getUpdateUsername() {
        return updateUsername;
    }

    public void setUpdateUsername(String updateUsername) {
        this.updateUsername = updateUsername == null ? null : updateUsername.trim();
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getInsertUpdateRemark() {
        return insertUpdateRemark;
    }

    public void setInsertUpdateRemark(String insertUpdateRemark) {
        this.insertUpdateRemark = insertUpdateRemark == null ? null : insertUpdateRemark.trim();
    }

    public String getStatementType() {
        return statementType;
    }

    public void setStatementType(String statementType) {
        this.statementType = statementType == null ? null : statementType.trim();
    }

    public BigDecimal getBatchId() {
        return batchId;
    }

    public void setBatchId(BigDecimal batchId) {
        this.batchId = batchId;
    }

    public BigDecimal getEasAmount() {
        return easAmount;
    }

    public void setEasAmount(BigDecimal easAmount) {
        this.easAmount = easAmount;
    }

    public BigDecimal getTotalWetTon() {
        return totalWetTon;
    }

    public void setTotalWetTon(BigDecimal totalWetTon) {
        this.totalWetTon = totalWetTon;
    }

    public BigDecimal getStatementStatus() {
        return statementStatus;
    }

    public void setStatementStatus(BigDecimal statementStatus) {
        this.statementStatus = statementStatus;
    }

    public BigDecimal getTotalPreviewTon() {
        return totalPreviewTon;
    }

    public void setTotalPreviewTon(BigDecimal totalPreviewTon) {
        this.totalPreviewTon = totalPreviewTon;
    }

    public BigDecimal getTotalPreviewFee() {
        return totalPreviewFee;
    }

    public void setTotalPreviewFee(BigDecimal totalPreviewFee) {
        this.totalPreviewFee = totalPreviewFee;
    }

    public BigDecimal getUnitPriceId() {
        return unitPriceId;
    }

    public void setUnitPriceId(BigDecimal unitPriceId) {
        this.unitPriceId = unitPriceId;
    }

    public BigDecimal getTotalWaterFee() {
        return totalWaterFee;
    }

    public void setTotalWaterFee(BigDecimal totalWaterFee) {
        this.totalWaterFee = totalWaterFee;
    }

    public BigDecimal getTotalLoadTon() {
        return totalLoadTon;
    }

    public void setTotalLoadTon(BigDecimal totalLoadTon) {
        this.totalLoadTon = totalLoadTon;
    }

    public BigDecimal getTotalLoadPercent() {
        return totalLoadPercent;
    }

    public void setTotalLoadPercent(BigDecimal totalLoadPercent) {
        this.totalLoadPercent = totalLoadPercent;
    }

    public BigDecimal getTotalBalanceTon() {
        return totalBalanceTon;
    }

    public void setTotalBalanceTon(BigDecimal totalBalanceTon) {
        this.totalBalanceTon = totalBalanceTon;
    }

    public String getResultOutPortTime() {
        return resultOutPortTime;
    }

    public void setResultOutPortTime(String resultOutPortTime) {
        this.resultOutPortTime = resultOutPortTime == null ? null : resultOutPortTime.trim();
    }

    public String getBillNo() {
        return billNo;
    }

    public void setBillNo(String billNo) {
        this.billNo = billNo == null ? null : billNo.trim();
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", statementId=").append(statementId);
        sb.append(", statementNo=").append(statementNo);
        sb.append(", statementShipperId=").append(statementShipperId);
        sb.append(", statementTotalAmount=").append(statementTotalAmount);
        sb.append(", statementDate=").append(statementDate);
        sb.append(", insertUsername=").append(insertUsername);
        sb.append(", insertTime=").append(insertTime);
        sb.append(", updateUsername=").append(updateUsername);
        sb.append(", updateTime=").append(updateTime);
        sb.append(", insertUpdateRemark=").append(insertUpdateRemark);
        sb.append(", statementType=").append(statementType);
        sb.append(", batchId=").append(batchId);
        sb.append(", easAmount=").append(easAmount);
        sb.append(", totalWetTon=").append(totalWetTon);
        sb.append(", statementStatus=").append(statementStatus);
        sb.append(", totalPreviewTon=").append(totalPreviewTon);
        sb.append(", totalPreviewFee=").append(totalPreviewFee);
        sb.append(", unitPriceId=").append(unitPriceId);
        sb.append(", totalWaterFee=").append(totalWaterFee);
        sb.append(", totalLoadTon=").append(totalLoadTon);
        sb.append(", totalLoadPercent=").append(totalLoadPercent);
        sb.append(", totalBalanceTon=").append(totalBalanceTon);
        sb.append(", resultOutPortTime=").append(resultOutPortTime);
        sb.append(", billNo=").append(billNo);
        sb.append(", serialVersionUID=").append(serialVersionUID);
        sb.append("]");
        return sb.toString();
    }
}