package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.BmsportHandlingFeeMapper;
import com.steerinfo.dil.mapper.BmsshipFeeMapper;
import com.steerinfo.dil.mapper.BmsshipStatementMapper;
import com.steerinfo.dil.model.BmsportHandlingFee;
import com.steerinfo.dil.model.BmsshipFee;
import com.steerinfo.dil.model.BmsshipStatement;
import com.steerinfo.dil.service.IBmsportHandlingFeeService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.xml.crypto.Data;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/27 14:14
 * @Version:V2.0
 */
@Service
public class BmsportHandlingFeeServiceImpl implements IBmsportHandlingFeeService {

    @Autowired
    BmsportHandlingFeeMapper bmsportHandlingFeeMapper;
    @Autowired
    BmstruckFormulaServiceImpl bmstruckFormulaService;
    @Autowired
    BmsshipFeeMapper bmsshipFeeMapper;
    @Autowired
    BmsshipStatementMapper bmsshipStatementMapper;

    /**
     * 修改港口装卸费结算
     * @param bmsportHandlingFee
     * @return
     */
    @Override
    public int update(BmsportHandlingFee bmsportHandlingFee) {
        bmsportHandlingFee.setUpdateTime(new Date());
        return bmsportHandlingFeeMapper.updateByPrimaryKeySelective(bmsportHandlingFee);
    }

    /**
     * 逻辑删除港口装卸费结算
     * @param feeId
     * @return
     */
    @Override
    public int deleteByUpdate(BigDecimal feeId) {
        BmsportHandlingFee bmsportHandlingFee = bmsportHandlingFeeMapper.selectByPrimaryKey(feeId);
        bmsportHandlingFee.setDeleted(new BigDecimal(1));
        return bmsportHandlingFeeMapper.updateByPrimaryKeySelective(bmsportHandlingFee);
    }

    /**
     * 新增港口装卸费结算
     * @param map
     * @return
     */
    @Override
    public int insert(Map<String,Object> map) throws Exception {
        Map<String,Object> mapVal = (Map<String, Object>) map.get("mapVal");
        Map<String,Object> rowMap = (Map<String, Object>) map.get("rowMap");
        BigDecimal materialId = new BigDecimal((Integer) rowMap.get("materialId")) ;
        String feeForeignShipName = (String) rowMap.get("foreignShipName");
        BigDecimal feeId = selectMaxId();
        BigDecimal feeMaterialTonnage = new BigDecimal((String) mapVal.get("feeMaterialTonnage"));
        List<Map<String,Object>> priceList = bmsportHandlingFeeMapper.getPriceId();
        Map<String, Object> priceMap = priceList.get(0);
        BigDecimal priceId = (BigDecimal) priceMap.get("priceId");
        BigDecimal fee = bmstruckFormulaService.generatePortHandlingFee(feeMaterialTonnage, priceId);
        DecimalFormat df = new DecimalFormat("0.00");
        String format = df.format(fee.doubleValue());
        BigDecimal feeValue = new BigDecimal(format);
        BmsportHandlingFee bmsportHandlingFee = new BmsportHandlingFee();
        bmsportHandlingFee.setDeleted(new BigDecimal(0));
        bmsportHandlingFee.setPriceId(priceId);
        bmsportHandlingFee.setFeeId(feeId);
        bmsportHandlingFee.setFeeMaterialTonnage(feeMaterialTonnage);
        bmsportHandlingFee.setFeeValue(feeValue);
        bmsportHandlingFee.setMaterialId(materialId);
        bmsportHandlingFee.setFeeForeignShipName(feeForeignShipName);

        // 设置常规字段
        bmsportHandlingFee.setInsertTime(new Date());
        bmsportHandlingFee.setInsertUsername("admin");
        bmsportHandlingFee.setUpdateTime(new Date());
        bmsportHandlingFee.setUpdateUsername("admin");
        bmsportHandlingFee.setInsertUpdateRemark("无");
        return bmsportHandlingFeeMapper.insertSelective(bmsportHandlingFee);
    }

    /**
     * 展示港口装卸费列表
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getPortHandlingFeeList(Map<String, Object> mapValue) {
        return bmsportHandlingFeeMapper.getPortHandlingFeeList(mapValue);
    }

    /**
     * 查询最大id
     * @return
     */
    @Override
    public BigDecimal selectMaxId() {
        BigDecimal feeId = bmsportHandlingFeeMapper.selectMaxId();
        return feeId == null ? new BigDecimal(1) : new BigDecimal(feeId.intValue() + 1);
    }

    /**
     * 查询修改渲染数据
     * @param feeId
     * @return
     */
    @Override
    public List<Map<String,Object>> getFeeToUpdate(BigDecimal feeId) {
        return bmsportHandlingFeeMapper.getFeeToUpdate(feeId);
    }

    /**
     * 获取物资id下拉
     * @return
     */
    @Override
    public List<Map<String, Object>> getMaterialId() {
        return bmsportHandlingFeeMapper.getMaterialId();
    }

    /**
     * 获取单价下拉
     * @return
     */
    @Override
    public List<Map<String, Object>> getPriceId() {
        return bmsportHandlingFeeMapper.selectPriceId();
    }


    @Override
    @Transactional(rollbackFor = {Exception.class})
    public int addPortHandlingFeeSecond(Map<String, Object> map) throws Exception {
        //获取运输单价
        BigDecimal Fee=null;
        long makeTime = 0;
        BigDecimal unitPrice = DataChange.dataToBigDecimal(map.get("unitPrice"));
        //水运单总吨位
        BigDecimal tonnage =DataChange.dataToBigDecimal(map.get("realTonnage"));
        BigDecimal batchId =DataChange.dataToBigDecimal(map.get("batchId"));
        BigDecimal purchaseOrderId =DataChange.dataToBigDecimal(map.get("purchaseOrderId"));
        //三程船字段
        BigDecimal portId=DataChange.dataToBigDecimal(map.get("portId"));
        BigDecimal previewFee=DataChange.dataToBigDecimal(map.get("previewFee"));
        BigDecimal previewTonnage=DataChange.dataToBigDecimal(map.get("previewTonnage"));
        BigDecimal loadWater=DataChange.dataToBigDecimal(map.get("loadWater"));
        BigDecimal enFacotoryWater=DataChange.dataToBigDecimal(map.get("enFacotoryWater"));
        BigDecimal makeTonnage=DataChange.dataToBigDecimal(map.get("makeTonnage"));
        BigDecimal makeFee=DataChange.dataToBigDecimal(map.get("actuallyMoney"));
        BigDecimal totalResultId=DataChange.dataToBigDecimal(map.get("totalResultId"));
        if(map.get("makeTime")!=null) {
             makeTime = (long) map.get("makeTime");
        }else {
           throw new Exception("请填写制票日期");
        }
        //获取userId
        String userId = (String) map.get("userId");
        //根据userId查找姓名
        String personnelName = bmsshipFeeMapper.getPersonnelNameByUserId(userId);
        //单价*总吨位
        BmsshipFee bmsshipFee =new BmsshipFee();
        //获取主键id
        bmsshipFee.setResultId(bmsshipFeeMapper.MaxId());
        bmsshipFee.setRealTonnage(tonnage);
        bmsshipFee.setFeeType(DataChange.dataToBigDecimal(map.get("feeType")));
        bmsshipFee.setPreviewTonnage(previewTonnage);
        bmsshipFee.setPreviewFee(previewFee);
        bmsshipFee.setLoadWaterTonnage(loadWater);
        bmsshipFee.setEnWaterTonnage(enFacotoryWater);
        bmsshipFee.setMakeTonnage(makeTonnage);
        bmsshipFee.setFeeMake(makeFee);
        bmsshipFee.setPortId(portId);
        bmsshipFee.setTotalResultId(totalResultId);
        bmsshipFee.setImage((String) map.get("image"));
        bmsshipFee.setInsertTime(new Date());
        bmsshipFee.setDeleted(new BigDecimal(0));
        if (personnelName!=null) {
            bmsshipFee.setInsertUsername(personnelName);
        }else {
            bmsshipFee.setInsertUsername(userId);
        }
        bmsshipFee.setMakeTime(new Date(makeTime));
        bmsshipFee.setBatchId(batchId);
        bmsshipFee.setPurchaseOrderId(purchaseOrderId);
        //设置总运费
        if (unitPrice!=null&&unitPrice.intValue()!=0) {
             Fee = unitPrice.multiply(tonnage);
            bmsshipFee.setUnitPrice(unitPrice);
            bmsshipFee.setUnitPriceId(DataChange.dataToBigDecimal(map.get("unitPriceId")));
            if (DataChange.dataToBigDecimal(map.get("fee")).setScale(2,BigDecimal.ROUND_HALF_UP).compareTo(Fee.setScale(2,BigDecimal.ROUND_HALF_UP)) == 0) {
                bmsshipFee.setFee(Fee);

            } else {
               throw new Exception("费用不一致");
            }
        }else {
            bmsshipFee.setFee(DataChange.dataToBigDecimal(map.get("fee")));
        }
        if (map.get("resultRemarks")!=null){
            bmsshipFee.setInsertUpdateRemark((String) map.get("resultRemarks"));
        }
        int i = bmsshipFeeMapper.insertSelective(bmsshipFee);
        return i;
    }

    @Override
    public List<Map<String, Object>> selectPortFeeSecondList(Map<String, Object> map) {
        List<Map<String, Object>> mapList = bmsportHandlingFeeMapper.selectPortFeeSecondList(map);
        return mapList;
    }

    @Override
    public String downloadBmsshipOrder(Integer resultId) {
        return bmsportHandlingFeeMapper.downloadBmsshipOrder(resultId);
    }

    @Override
    public List<Map<String, Object>> getBmsshipFee(Integer id) {
        return bmsportHandlingFeeMapper.getBmsshipFee(id);
    }

    //修改港口装卸费
    @Override
    public int updatePortHandlingFee(Map<String, Object> map) {
        BigDecimal purchaseOrderId=null;
        BigDecimal resultId =DataChange.dataToBigDecimal(map.get("resultId"));
        //水运单总吨位
        BigDecimal tonnage =DataChange.dataToBigDecimal(map.get("realTonnage"));
        if(map.get("purchaseOrderId")!=null) {
             purchaseOrderId = DataChange.dataToBigDecimal(map.get("purchaseOrderId"));
        }
        long makeTime =(long) map.get("makeTime");
        //获取userId
        String userId = (String) map.get("userId");
        //根据userId查找姓名
        String personnelName = bmsshipFeeMapper.getPersonnelNameByUserId(userId);
        //单价*总吨位
        BmsshipFee bmsshipFee =new BmsshipFee();
        //获取主键id
        bmsshipFee.setResultId(resultId);
        bmsshipFee.setRealTonnage(tonnage);
        bmsshipFee.setFeeType(DataChange.dataToBigDecimal(map.get("feeType")));
        bmsshipFee.setImage((String) map.get("image"));
        bmsshipFee.setInsertTime(new Date());
        bmsshipFee.setDeleted(new BigDecimal(0));
        if (personnelName!=null) {
            bmsshipFee.setInsertUsername(personnelName);
        }else {
            bmsshipFee.setInsertUsername(userId);
        }

        bmsshipFee.setMakeTime(new Date(makeTime));
        if (map.get("batchId")!=null) {
            BigDecimal batchId =DataChange.dataToBigDecimal(map.get("batchId"));
            bmsshipFee.setBatchId(batchId);
        }

        bmsshipFee.setPurchaseOrderId(purchaseOrderId);
        //设置总运费
        //获取运输单价
        if (map.get("unitPrice")!=null) {
            BigDecimal unitPrice = DataChange.dataToBigDecimal(map.get("unitPrice"));
            bmsshipFee.setUnitPrice(unitPrice);
            if (map.get("unitPriceId") != null) {
                bmsshipFee.setUnitPriceId(DataChange.dataToBigDecimal(map.get("unitPriceId")));
            }
            BigDecimal Fee = unitPrice.multiply(tonnage);
            if (DataChange.dataToBigDecimal(map.get("fee")).compareTo(Fee) == 0) {
                bmsshipFee.setFee(Fee);
            } else {
                return -2;
            }
        }else {
            bmsshipFee.setFee(DataChange.dataToBigDecimal(map.get("fee")));
        }
        if (map.get("resultRemarks")!=null){
            bmsshipFee.setInsertUpdateRemark((String) map.get("resultRemarks"));
        }
        int i = bmsshipFeeMapper.updateByPrimaryKeySelective(bmsshipFee);
        return i;
    }

    @Override
    public int deletePortHandlingFeeSecond(BigDecimal feeId) {
        BmsshipFee bmsshipFee =new BmsshipFee();
        bmsshipFee.setResultId(feeId);
        bmsshipFee.setDeleted(new BigDecimal(1));
        return bmsshipFeeMapper.updateByPrimaryKeySelective(bmsshipFee);
    }

    @Override
    public Map<String, Object> getTrainDetailsByBatch(BigDecimal batchId) {
        Map<String,Object> map=new HashMap<>();
        map.put("batchId",batchId);
        List<Map<String,Object>> list=bmsportHandlingFeeMapper.getTrainDetailsByBatch(map);
        if(list!=null && list.size()>0)
            return list.get(0);
        else
            return null;
    }

    @Override
    public Map<String, Object> getTruckDetailsByBatch(BigDecimal batchId) {
        Map<String,Object> map=new HashMap<>();
        map.put("batchId",batchId);
        List<Map<String,Object>> list=bmsportHandlingFeeMapper.getTruckDetailsByBatch(map);
        if(list!=null && list.size()>0)
            return list.get(0);
        else
            return null;
    }

    @Override
    public List<Map<String, Object>> findLoadByBatch(Map<String,Object> map) {
        return bmsportHandlingFeeMapper.findLoadByBatch(map);
    }

    @Override
    public List<Map<String, Object>> getShipFeeStatement(Map<String,Object> map) {
        return bmsportHandlingFeeMapper.getShipFeeStatement(map);
    }

    @Override
    public List<Map<String, Object>> getShipFeeStatemented(Map<String,Object> map) {
        return bmsportHandlingFeeMapper.getShipFeeStatemented(map);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int addShipFeeStatement(Map<String, Object> map) throws Exception {
        //生成账单
        BmsshipStatement bmsshipStatement=new BmsshipStatement();
        BigDecimal statementId = bmsshipStatementMapper.selectMaxId();
        bmsshipStatement.setStatementId(statementId);
        bmsshipStatement.setStatementType("进口矿计费账单");
        bmsshipStatement.setBatchId(DataChange.dataToBigDecimal(map.get("batchId")));
        bmsshipStatement.setUnitPriceId(DataChange.dataToBigDecimal(map.get("unitPriceId")));
        bmsshipStatement.setTotalLoadTon(DataChange.dataToBigDecimal(map.get("monthLoadTonnage")).setScale(2,BigDecimal.ROUND_HALF_UP));//月份装船吨位
        bmsshipStatement.setTotalLoadPercent(DataChange.dataToBigDecimal(map.get("monthLoadingProportion")));//月份装船比例
        bmsshipStatement.setTotalBalanceTon(DataChange.dataToBigDecimal(map.get("monthRealTonnage")).setScale(2,BigDecimal.ROUND_HALF_UP));//月份结算吨位
        bmsshipStatement.setTotalWetTon(DataChange.dataToBigDecimal(map.get("monthMakeTonnage")).setScale(2,BigDecimal.ROUND_HALF_UP));//月份开票吨位
        bmsshipStatement.setStatementTotalAmount(DataChange.dataToBigDecimal(map.get("statementTotalAmount")).setScale(2,BigDecimal.ROUND_HALF_UP));//开票金额
        bmsshipStatement.setTotalPreviewTon(DataChange.dataToBigDecimal(map.get("totalPreviewTonnage")).setScale(2,BigDecimal.ROUND_HALF_UP));//预开总吨位
        bmsshipStatement.setTotalPreviewFee(DataChange.dataToBigDecimal(map.get("totalPreviewFee")).setScale(2,BigDecimal.ROUND_HALF_UP));//预开总金额
        bmsshipStatement.setResultOutPortTime(map.get("resultOutPortTime")+"");
        bmsshipStatement.setTotalWaterFee(DataChange.dataToBigDecimal(map.get("inspectionsFee")).setScale(2,BigDecimal.ROUND_HALF_UP));
        bmsshipStatement.setStatementNo("BMSSF"+new Date().getTime());
        bmsshipStatement.setStatementStatus(DataChange.dataToBigDecimal(map.get("statementStatus")));
        bmsshipStatement.setInsertTime(new Date());
        //新增
        return bmsshipStatementMapper.insertSelective(bmsshipStatement);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int editShipFeeStatement(Map<String, Object> map) throws Exception {
        BmsshipStatement bmsshipStatement=new BmsshipStatement();
        bmsshipStatement.setStatementId(DataChange.dataToBigDecimal(map.get("statementId")));
        bmsshipStatement.setStatementType("进口矿计费账单");
        bmsshipStatement.setBatchId(DataChange.dataToBigDecimal(map.get("batchId")));
        bmsshipStatement.setUnitPriceId(DataChange.dataToBigDecimal(map.get("unitPriceId")));
        bmsshipStatement.setTotalLoadTon(DataChange.dataToBigDecimal(map.get("monthLoadTonnage")).setScale(2,BigDecimal.ROUND_HALF_UP));//月份装船吨位
        bmsshipStatement.setTotalLoadPercent(DataChange.dataToBigDecimal(map.get("monthLoadingProportion")));//月份装船比例
        bmsshipStatement.setTotalBalanceTon(DataChange.dataToBigDecimal(map.get("monthRealTonnage")).setScale(2,BigDecimal.ROUND_HALF_UP));//月份结算吨位
        bmsshipStatement.setTotalWetTon(DataChange.dataToBigDecimal(map.get("monthMakeTonnage")).setScale(2,BigDecimal.ROUND_HALF_UP));//月份开票吨位
        bmsshipStatement.setStatementTotalAmount(DataChange.dataToBigDecimal(map.get("statementTotalAmount")).setScale(2,BigDecimal.ROUND_HALF_UP));//开票金额
        bmsshipStatement.setTotalPreviewTon(DataChange.dataToBigDecimal(map.get("totalPreviewTonnage")).setScale(2,BigDecimal.ROUND_HALF_UP));//预开总吨位
        bmsshipStatement.setTotalPreviewFee(DataChange.dataToBigDecimal(map.get("totalPreviewFee")).setScale(2,BigDecimal.ROUND_HALF_UP));//预开总金额
        bmsshipStatement.setStatementNo("BMSSF"+new Date().getTime());
        bmsshipStatement.setResultOutPortTime(map.get("resultOutPortTime")+"");
        bmsshipStatement.setTotalWaterFee(DataChange.dataToBigDecimal(map.get("inspectionsFee")).setScale(2,BigDecimal.ROUND_HALF_UP));
        bmsshipStatement.setStatementStatus(DataChange.dataToBigDecimal(map.get("statementStatus")));
        bmsshipStatement.setUpdateTime(new Date());
        //修改
        return bmsshipStatementMapper.updateByPrimaryKeySelective(bmsshipStatement);
    }


    @Override
    public Map<BigDecimal, BigDecimal> findTotalTonnage() {
        List<Map<String, Object>> list= bmsportHandlingFeeMapper.findTotalTonnage();
        Map<BigDecimal,BigDecimal> map=new HashMap();
        for(Map<String,Object> temp:list){
            BigDecimal batchId= DataChange.dataToBigDecimal(temp.get("batchId"));
            BigDecimal totalTonnage=DataChange.dataToBigDecimal(temp.get("totalTonnage"));
            map.put(batchId,totalTonnage);
        }
        return map;
    }

    @Override
    public BigDecimal getEnFactoryTonnage(Map<String,Object> map) {
        //获取进厂湿吨
        List<Map<String, Object>> trainList=bmsportHandlingFeeMapper.getTrainDetailsByBatch(map);
        List<Map<String, Object>> truckList=bmsportHandlingFeeMapper.getTruckDetailsByBatch(map);
        BigDecimal train=new BigDecimal(0),truck=new BigDecimal(0);
        if(trainList.size()>0){
            train=DataChange.dataToBigDecimal(trainList.get(0).get("realWeight"));
        }
        if(truckList.size()>0){
            truck=DataChange.dataToBigDecimal(truckList.get(0).get("realWeight"));
        }
        return truck.add(train);
    }
}
